@@ -4,7 +4,7 @@ use strict;
 
 package MooseX::Has::Sugar::Minimal;
 
-our $VERSION = '1.000004';
+our $VERSION = '1.000006';
 
 # ABSTRACT: Less Sugary Syntax for moose 'has' fields
 
@@ -72,7 +72,7 @@ MooseX::Has::Sugar::Minimal - Less Sugary Syntax for moose 'has' fields
 
 =head1 VERSION
 
-version 1.000004
+version 1.000006
 
 =head1 SYNOPSIS
 
@@ -146,11 +146,11 @@ If you do however want to use them in conjunction, specific imports must
 
 =head1 AUTHOR
 
-Kent Fredric <kentnl at cpan.org>
+Kent Fredric <kentnl@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Kent Fredric.
+This software is copyright (c) 2017 by Kent Fredric <kentfredric@gmail.com>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
